@@ -109,7 +109,7 @@ bool Settings::Load()
 
     settings->beginGroup(m_AppletId);
 
-    CounterStyle = (Counter::widgetSize)settings->value("counterstyle", true).toInt();
+    CounterStyle = (Counter::widgetSize)settings->value("counterstyle", Counter::widgetMinimal).toInt();
     Animation = settings->value("animation", true).toBool();
     WidgetWidth = settings->value("widgetwidth", 200).toInt();
     StyleSheetName = settings->value("stylesheet", "Default").toString();
