@@ -60,19 +60,21 @@ void CounterWidget::CreateWidgets(Settings* settings)
 #endif
     int index = 0;
     foreach (SogliaItem s, m_Counter->Soglie){
-        m_Bar = new QProgressBar(this);
-        m_Bar->setMinimum(0);
-        if (s.Soglia > 0)
-            m_Bar->setMaximum(s.Soglia);
-        else
-            m_Bar->setMaximum(100);
-        m_Bar->setValue(s.Utilizzato);
-        if (settings)
-            SetPercentageVisible(settings->ShowPercentage);
-        m_Layout->addWidget(m_Bar, row, 0, 1, 2);
-
-        if (m_Counter->WidgetSize == Counter::widgetMedium){
+        if (m_Counter->WidgetSize != Counter::widgetTextOnly){
+            m_Bar = new QProgressBar(this);
+            m_Bar->setMinimum(0);
+            if (s.Soglia > 0)
+                m_Bar->setMaximum(s.Soglia);
+            else
+                m_Bar->setMaximum(100);
+            m_Bar->setValue(s.Utilizzato);
+            if (settings)
+                SetPercentageVisible(settings->ShowPercentage);
+            m_Layout->addWidget(m_Bar, row, 0, 1, 2);
             row++;
+        }
+
+        if (m_Counter->WidgetSize == Counter::widgetMedium || m_Counter->WidgetSize == Counter::widgetTextOnly){
             QLabel* lbl = new QLabel(this);
             lbl->setAlignment(Qt::AlignLeft);
             lbl->setText(tr("Util./Tot."));
